pub fn block_rank(
module: &mut PoWModule,
block: &BlockInfo,
) -> Result<(BigUint, BigUint, BigUint)>Expand description
Compute a block’s rank, assuming that its valid, for provided PoW module. Returns next mine difficulty, along with the computed rank.
Block’s rank is the tuple of its squared mining target distance from max 32 bytes int, along with its squared RandomX hash number distance from max 32 bytes int. Genesis block has rank (0, 0).